@@ -3,9 +3,10 @@
     --------
 
 """
-from zeep.xsd.const import Nil, SkipValue  # noqa
+
+from zeep.xsd.const import Nil, SkipValue
 from zeep.xsd.elements import *  # noqa
-from zeep.xsd.schema import Schema  # noqa
+from zeep.xsd.schema import Schema as Schema
 from zeep.xsd.types import *  # noqa
 from zeep.xsd.types.builtins import *  # noqa
 from zeep.xsd.valueobjects import *  # noqa
