@@ -1,5 +1,3 @@
-import io
-
 import pytest
 from lxml import etree
 
@@ -12,7 +10,7 @@ def transport():
     transport = DummyTransport()
     transport.bind(
         "http://schemas.xmlsoap.org/soap/encoding/",
-        load_xml(io.open("tests/wsdl_files/soap-enc.xsd", "r").read().encode("utf-8")),
+        load_xml(open("tests/wsdl_files/soap-enc.xsd").read().encode("utf-8")),
     )
     return transport
 
@@ -322,7 +320,7 @@ def test_soap_array_parse_remote_ns():
     transport = DummyTransport()
     transport.bind(
         "http://schemas.xmlsoap.org/soap/encoding/",
-        load_xml(io.open("tests/wsdl_files/soap-enc.xsd", "r").read().encode("utf-8")),
+        load_xml(open("tests/wsdl_files/soap-enc.xsd").read().encode("utf-8")),
     )
 
     schema = xsd.Schema(
@@ -392,7 +390,7 @@ def test_wsdl_array_type():
     transport = DummyTransport()
     transport.bind(
         "http://schemas.xmlsoap.org/soap/encoding/",
-        load_xml(io.open("tests/wsdl_files/soap-enc.xsd", "r").read().encode("utf-8")),
+        load_xml(open("tests/wsdl_files/soap-enc.xsd").read().encode("utf-8")),
     )
 
     schema = xsd.Schema(
@@ -466,7 +464,7 @@ def test_soap_array_parse():
     transport = DummyTransport()
     transport.bind(
         "http://schemas.xmlsoap.org/soap/encoding/",
-        load_xml(io.open("tests/wsdl_files/soap-enc.xsd", "r").read().encode("utf-8")),
+        load_xml(open("tests/wsdl_files/soap-enc.xsd").read().encode("utf-8")),
     )
 
     schema = xsd.Schema(
